@@ -1,3 +1,4 @@
+from .ProcessBase import ProcessBase
 from .WindowShellBase import WindowShellBase
 
 
@@ -5,7 +6,7 @@ class Command(WindowShellBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-    def launch(self):
+    def start(self) -> ProcessBase:
         pass
 
     def __enter__(self):
