@@ -1,6 +1,7 @@
 from typing import Callable, Optional, Iterable
 
 from .ControlBase import ControlBase
+from difflib import get_close_matches
 
 
 class ComboBox(ControlBase):
@@ -21,5 +22,15 @@ class ComboBox(ControlBase):
                       callbackOnEachValue: Optional[Callable[[str], bool]] = None):
         pass
 
-    def select(self, value: Optional[str] = None, index: int = -1):
-        pass
+    def select(self, value: Optional[str] = None, index: int = -1) -> bool:
+        if self.isExist():
+            try:
+                cb = self.automationInstance
+                matches = get_close_matches(value, cb.texts())
+                if matches:
+                    self.automationInstance.select(matches[0])
+                    return True
+                else:
+                    return False
+            except:
+                return False
